@@ -338,12 +338,13 @@ sub print_section {
                 $tmfunc_name =~ s/\*/Ptr/g;
                 $tmfunc_name =~ s/\s/_/g;
                 unless ($gen_funcs{$tmfunc_name}) {
+                    my $arg = 'arg';
                     my $other = {
                         var     => 'var',
                         type    => $class,
                         subtype => $subtype,
                         ntype   => $ntype,
-                        arg     => 'arg',
+                        arg     => $arg,
                     };
                     if ($is_input) {
                         $other->{num}          = -1; # not on stack
@@ -354,7 +355,7 @@ sub print_section {
                     $meth = $is_input ? 'eval_input_typemap_code' : 'eval_output_typemap_code';
                     my $tmcode = $tmap->code;
                     my $code = $self->$meth("qq\a$tmcode\a", $other);
-                    my $arg_init = (!$is_input && $tmcode =~ /^\s*\$arg\s*=\s*\NULL\s*;\s*$/m) ? '' : ' = newSV(0)';
+                    my $arg_init = (!$is_input && $code =~ /^\s*$arg\s*=\s*\NULL\s*;\s*$/m) ? '' : ' = newSV(0)';
                     my $tmfunc_code = $self->typemap_inline_func($tmfunc_name, $class, $code, $arg_init, $is_input, \@args, $tmap->{_init_code});
                     $gen_funcs{$tmfunc_name} = $tmfunc_code;
                 }
